@@ -47,7 +47,7 @@ typedef enum {
   FAKESINK_STATE_ERROR_PAUSED_PLAYING,
   FAKESINK_STATE_ERROR_PLAYING_PAUSED,
   FAKESINK_STATE_ERROR_PAUSED_READY,
-  FAKESINK_STATE_ERROR_READY_NULL,
+  FAKESINK_STATE_ERROR_READY_NULL
 } GstFakeSinkStateError;
 
 typedef struct _GstFakeSink GstFakeSink;
@@ -75,8 +75,6 @@ struct _GstFakeSinkClass {
 
 GType gst_fakesink_get_type(void);
 
-gboolean gst_fakesink_factory_init (GstElementFactory *factory);
-
 G_END_DECLS
 
 #endif /* __GST_FAKESINK_H__ */
