@@ -51,6 +51,8 @@ struct _GstFdSrc {
 
   /* fd */
   gint fd;
+  gboolean interrupted;
+  gchar *uri;
 
   gulong curoffset; /* current offset in file */
   gulong blocksize; /* bytes per read */
