@@ -320,6 +320,7 @@ gst_filesrc_set_property (GObject * object, guint prop_id, const GValue * value,
     GParamSpec * pspec)
 {
   GstFileSrc *src;
+  gulong ul;
 
   /* it's not null if we got it, but it might not be ours */
   g_return_if_fail (GST_IS_FILESRC (object));
@@ -332,21 +333,19 @@ gst_filesrc_set_property (GObject * object, guint prop_id, const GValue * value,
       break;
     case ARG_BLOCKSIZE:
       src->block_size = g_value_get_ulong (value);
-      g_object_notify (G_OBJECT (src), "blocksize");
       break;
     case ARG_MMAPSIZE:
-      if ((src->mapsize % src->pagesize) == 0) {
-        src->mapsize = g_value_get_ulong (value);
-        g_object_notify (G_OBJECT (src), "mmapsize");
+      ul = g_value_get_ulong (value);
+      if ((ul % src->pagesize) == 0) {
+        src->mapsize = ul;
       } else {
         GST_INFO_OBJECT (src,
-            "invalid mapsize, must be a multiple of pagesize, which is %d",
-            src->pagesize);
+            "invalid mapsize %d, must be a multiple of pagesize, which is %d",
+            ul, src->pagesize);
       }
       break;
     case ARG_TOUCH:
       src->touch = g_value_get_boolean (value);
-      g_object_notify (G_OBJECT (src), "touch");
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -429,7 +428,8 @@ gst_filesrc_map_region (GstFileSrc * src, off_t offset, size_t size)
     return NULL;
   } else if (mmapregion == MAP_FAILED) {
     GST_WARNING_OBJECT (src, "mmap (0x%08lx, %d, 0x%llx) failed: %s",
-        (unsigned long) size, src->fd, offset, strerror (errno));
+        (unsigned long) size, src->fd, (unsigned long long) offset,
+        strerror (errno));
     return NULL;
   }
   GST_LOG_OBJECT (src, "mapped region %08lx+%08lx from file into memory at %p",
@@ -720,10 +720,9 @@ gst_filesrc_get (GstPad * pad)
       if (!gst_filesrc_check_filesize (src) || src->curoffset >= src->filelen) {
         GST_DEBUG_OBJECT (src, "eos %" G_GINT64_FORMAT " %" G_GINT64_FORMAT,
             src->curoffset, src->filelen);
+        gst_element_set_eos (GST_ELEMENT (src));
+        return GST_DATA (gst_event_new (GST_EVENT_EOS));
       }
-      gst_element_set_eos (GST_ELEMENT (src));
-      return GST_DATA (gst_event_new (GST_EVENT_EOS));
-
     }
   }
 #ifdef HAVE_MMAP
