@@ -28,10 +28,6 @@
 #  include "config.h"
 #endif
 
-/* This needs to be before glib.h, since it might be used in inline
- * functions */
-extern const char             *g_log_domain_gstreamer;
-
 #include <glib.h>
 
 #include <stdlib.h>
