@@ -1,5 +1,5 @@
 /* GStreamer
- * 
+ *
  * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
  *                    2000 Wim Taymans <wtay@chello.be>
  *
@@ -33,6 +33,7 @@
 #include "gstscheduler.h"
 #include "gstindex.h"
 #include "gstutils.h"
+#include "gstchildproxy.h"
 
 GST_DEBUG_CATEGORY_STATIC (bin_debug);
 #define GST_CAT_DEFAULT bin_debug
@@ -97,6 +98,7 @@ enum
 static void gst_bin_base_init (gpointer g_class);
 static void gst_bin_class_init (GstBinClass * klass);
 static void gst_bin_init (GstBin * bin);
+static void gst_bin_child_proxy_init (gpointer g_iface, gpointer iface_data);
 
 static GstElementClass *parent_class = NULL;
 static guint gst_bin_signals[LAST_SIGNAL] = { 0 };
@@ -123,9 +125,18 @@ gst_bin_get_type (void)
       NULL
     };
 
+    static const GInterfaceInfo child_proxy_info = {
+      gst_bin_child_proxy_init,
+      NULL,
+      NULL
+    };
+
     _gst_bin_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstBin", &bin_info, 0);
 
+    g_type_add_interface_static (_gst_bin_type, GST_TYPE_CHILD_PROXY,
+        &child_proxy_info);
+
     GST_DEBUG_CATEGORY_INIT (bin_debug, "bin", GST_DEBUG_BOLD,
         "debugging info for the 'bin' container element");
   }
@@ -213,6 +224,28 @@ gst_bin_init (GstBin * bin)
   bin->children = NULL;
 }
 
+static GstObject *
+gst_bin_child_proxy_get_child_by_index (GstChildProxy * child_proxy,
+    guint index)
+{
+  return g_list_nth_data (GST_BIN (child_proxy)->children, index);
+}
+
+guint
+gst_bin_child_proxy_get_children_count (GstChildProxy * child_proxy)
+{
+  return GST_BIN (child_proxy)->numchildren;
+}
+
+static void
+gst_bin_child_proxy_init (gpointer g_iface, gpointer iface_data)
+{
+  GstChildProxyInterface *iface = g_iface;
+
+  iface->get_children_count = gst_bin_child_proxy_get_children_count;
+  iface->get_child_by_index = gst_bin_child_proxy_get_child_by_index;
+}
+
 /**
  * gst_bin_new:
  * @name: name of new bin
@@ -265,7 +298,7 @@ gst_bin_get_clock (GstBin * bin)
  * @bin: the bin to set the clock for
  * @clock: the clock to use.
  *
- * Force the bin to use the given clock. Use NULL to 
+ * Force the bin to use the given clock. Use NULL to
  * force it to use no clock at all.
  */
 void
@@ -433,7 +466,7 @@ gst_bin_unset_element_sched (GstElement * element, GstScheduler * sched)
  * @bin: the bin to add the elements to
  * @element_1: the first element to add to the bin
  * @...: additional elements to add to the bin
- * 
+ *
  * Adds a NULL-terminated list of elements to a bin.  This function is
  * equivalent to calling #gst_bin_add() for each member of the list.
  */
@@ -492,8 +525,8 @@ gst_bin_add_func (GstBin * bin, GstElement * element)
     state_idx++;
   bin->child_states[state_idx]++;
 
-  /* now we have to deal with manager stuff 
-   * we can only do this if there's a scheduler: 
+  /* now we have to deal with manager stuff
+   * we can only do this if there's a scheduler:
    * if we're not a manager, and aren't attached to anything, we have no sched (yet) */
   sched = GST_ELEMENT_SCHED (bin);
   if (sched) {
@@ -529,6 +562,7 @@ gst_bin_add (GstBin * bin, GstElement * element)
 
   if (bclass->add_element) {
     bclass->add_element (bin, element);
+    gst_child_proxy_child_added (GST_OBJECT (bin), GST_OBJECT (element));
   } else {
     GST_ELEMENT_ERROR (bin, CORE, FAILED, (NULL),
         ("cannot add element %s to bin %s",
@@ -620,6 +654,7 @@ gst_bin_remove (GstBin * bin, GstElement * element)
   bclass = GST_BIN_GET_CLASS (bin);
 
   if (bclass->remove_element) {
+    gst_child_proxy_child_removed (GST_OBJECT (bin), GST_OBJECT (element));
     bclass->remove_element (bin, element);
   } else {
     g_warning ("cannot remove elements from bin %s\n", GST_ELEMENT_NAME (bin));
@@ -631,7 +666,7 @@ gst_bin_remove (GstBin * bin, GstElement * element)
  * @bin: the bin to remove the elements from
  * @element_1: the first element to remove from the bin
  * @...: NULL-terminated list of elements to remove from the bin
- * 
+ *
  * Remove a list of elements from a bin. This function is equivalent
  * to calling #gst_bin_remove with each member of the list.
  */
@@ -745,7 +780,7 @@ typedef gboolean (*GstBinForeachFunc) (GstBin * bin, GstElement * element,
  * @func: function to call on each child
  * @data: user data handed to each function call
  *
- * Calls @func on each child of the bin. If @func returns FALSE, 
+ * Calls @func on each child of the bin. If @func returns FALSE,
  * gst_bin_foreach() immediately returns.
  * It is assumed that calling @func may alter the set of @bin's children. @func
  * will only be called on children that were in @bin when gst_bin_foreach() was
@@ -1122,7 +1157,7 @@ gst_bin_get_all_by_interface (GstBin * bin, GType interface)
  *
  * Tries to set the state of the children of this bin to the same state of the
  * bin by calling gst_element_set_state for each child not already having a
- * synchronized state. 
+ * synchronized state.
  *
  * Returns: The worst return value of any gst_element_set_state. So if one child
  *          returns #GST_STATE_FAILURE while all others return #GST_STATE_SUCCESS
@@ -1180,7 +1215,7 @@ gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
   if (GST_OBJECT_CLASS (parent_class)->save_thyself)
     GST_OBJECT_CLASS (parent_class)->save_thyself (GST_OBJECT (bin), parent);
 
-  childlist = xmlNewChild (parent, NULL, "children", NULL);
+  childlist = xmlNewChild (parent, NULL, (guchar *) "children", NULL);
 
   GST_CAT_INFO (GST_CAT_XML, "[%s]: saving %d children",
       GST_ELEMENT_NAME (bin), bin->numchildren);
@@ -1188,7 +1223,7 @@ gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
   children = bin->children;
   while (children) {
     child = GST_ELEMENT (children->data);
-    elementnode = xmlNewChild (childlist, NULL, "element", NULL);
+    elementnode = xmlNewChild (childlist, NULL, (guchar *) "element", NULL);
     gst_object_save_thyself (GST_OBJECT (child), elementnode);
     children = g_list_next (children);
   }
@@ -1203,12 +1238,12 @@ gst_bin_restore_thyself (GstObject * object, xmlNodePtr self)
   xmlNodePtr childlist;
 
   while (field) {
-    if (!strcmp (field->name, "children")) {
+    if (!strcmp ((char *) field->name, "children")) {
       GST_CAT_INFO (GST_CAT_XML, "[%s]: loading children",
           GST_ELEMENT_NAME (object));
       childlist = field->xmlChildrenNode;
       while (childlist) {
-        if (!strcmp (childlist->name, "element")) {
+        if (!strcmp ((char *) childlist->name, "element")) {
           GstElement *element =
               gst_xml_make_element (childlist, GST_OBJECT (bin));
 
