@@ -74,7 +74,7 @@ _gst_core_errors_init (void)
   TABLE (t, CORE, SEEK,
       N_("Internal GStreamer error: seek problem.  File a bug."));
   TABLE (t, CORE, CAPS,
-      N_("Internal GStreamer error: caps problem.  File a bug."));
+      N_("Internal GStreamer error: capabilities problem.  File a bug."));
   TABLE (t, CORE, TAG,
       N_("Internal GStreamer error: tag problem.  File a bug."));
 
@@ -96,7 +96,8 @@ _gst_library_errors_init (void)
           "to this error.  Please file a bug."));
   TABLE (t, LIBRARY, INIT, N_("Could not initialize supporting library."));
   TABLE (t, LIBRARY, SHUTDOWN, N_("Could not close supporting library."));
-  TABLE (t, LIBRARY, SETTINGS, N_("Could not close supporting library."));
+  TABLE (t, LIBRARY, SETTINGS, N_("Could not set settings."));
+  TABLE (t, LIBRARY, ENCODE, N_("Failed to encode image."));
 
   return t;
 }
