@@ -20,19 +20,24 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include "gst_private.h"
 #include <glib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
 
-#include "gst_private.h"
 
 #include "gstinfo.h"
 #include "gstregistry.h"
-#include "gstlog.h"
+#include "gstregistrypool.h"
 #include "gstmarshal.h"
 #include "gstfilter.h"
 
@@ -277,6 +282,12 @@ gboolean
 gst_registry_add_plugin (GstRegistry * registry, GstPlugin * plugin)
 {
   g_return_val_if_fail (GST_IS_REGISTRY (registry), FALSE);
+  if (gst_registry_pool_find_plugin (gst_plugin_get_name (plugin))) {
+    GST_WARNING_OBJECT (registry, "Not adding plugin %s, "
+        "because a plugin with same name already exists",
+        gst_plugin_get_name (plugin));
+    return FALSE;
+  }
 
   plugin->manager = registry;
   registry->plugins = g_list_prepend (registry->plugins, plugin);
