@@ -77,6 +77,7 @@ struct _GstValueTable {
   GstValueSerializeFunc serialize;
   GstValueDeserializeFunc deserialize;
 
+  /*< private >*/
   void *_gst_reserved [GST_PADDING];
 };
 
@@ -181,6 +182,7 @@ void		gst_value_register_subtract_func (GType		minuend_type,
 
 /* fixation */
 gboolean	gst_type_is_fixed		(GType type);
+gboolean	gst_value_is_fixed		(const GValue   *value);
 
 /* private */
 void		_gst_value_initialize		(void);
